;; FCG fragment that implements part of Bill Croft's analysis of the
;; aspectual contours of utterances in English.

;; Katrien Beuls and Paul Van Eecke
;; July 2018

(in-package :fcg)


(def-fcg-constructions aspect-grammar-croft
  :feature-types ((footprints set)
                  (subunits set)
                  (args sequence)
                  (ev-args sequence)
                  (sem-class set)
                  (form set-of-predicates)
                  (meaning set-of-predicates))
  :fcg-configurations ((:parse-goal-tests
                        :no-applicable-cxns :connected-semantic-network :connected-structure)
                       (:production-goal-tests
                        :no-applicable-cxns :no-meaning-in-root :connected-structure)
                       (:shuffle-cxns-before-application . t))
  :visualization-configurations ((:show-constructional-dependencies . nil)
                                 (:hide-features . (footprints)) 
                                 (:with-search-debug-data . t))
  :hierarchy-features (subunits)

(def-fcg-cxn man-noun-lex
             ((?man-unit
               (footprints (lex))
               (referent ?ref)
               (sem-cat (sem-class person)))
              <-
              (?man-unit
               (HASH meaning ((person man ?ref)))
               --
               (lex-id man)
               (footprints (not lex))
               (syn-cat (lex-class noun)
                        (agreement ?agr))))
             :disable-automatic-footprints t
             :cxn-set lex)


(def-fcg-cxn man-noun-morph
             ((?man-unit
               (footprints (morph)))
               <-
              (?man-unit
               (lex-id man)
               (footprints (not morph))
               (syn-cat (lex-class noun)
                        (agreement (person 3)
                                   (number sg)))
               --
               (HASH form ((string ?man-unit "man")))))
             :disable-automatic-footprints t
             :cxn-set morph)

(def-fcg-cxn sirtaki-noun-lex
             ((?sirtaki-unit
               (footprints (lex))
               (referent ?ref)
               (sem-cat (sem-class activity)))
              <-
              (?sirtaki-unit
               (HASH meaning ((dance sirtaki ?ref)))
               --
               (lex-id sirtaki)
               (footprints (not lex))
               (syn-cat (lex-class noun)
                        (agreement ?agr))))
             :disable-automatic-footprints t
             :cxn-set lex)


(def-fcg-cxn sirtaki-noun-morph
             ((?sirtaki-unit
               (footprints (morph)))
               <-
              (?sirtaki-unit
               (lex-id sirtaki)
               (footprints (not morph))
               (syn-cat (lex-class noun)
                        (agreement (person 3)
                                   (number sg)))
               --
               (HASH form ((string ?sirtaki-unit "sirtaki")))))
             :disable-automatic-footprints t
             :cxn-set morph)

(def-fcg-cxn dance-verb-lex
             ((?dance-unit
               (referent ?frame)
               (ev-args (?frame ?dancer))
               (sem-valence (actor ?dancer))
               (sem-cat (sem-class event)
                        (aspectual-contour undirected-activity)
                        (frame self-motion))
               (syn-cat (syn-function ?syn-function)
                        (finite ?fin)
                        (agreement ?agr)
                        (tam ?tam)))
              <-
              (?dance-unit
               (hash meaning ((frame self-motion dance ?frame)
                              (slot self-mover ?frame ?dancer)))
               --
               (syn-cat (lex-class verb))
               (lex-id dance)))
            :cxn-set lex)

(def-fcg-cxn dance->dances-morph
             ((?dances-unit
               (footprints (number morph)))
              <-
              (?dances-unit
               (footprints (not number morph))
               (syn-cat (lex-class verb)
                        (verb-form base-form)
                        (finite +)
                        (agreement (person 3)
                                   (number sg))
                        (tam (tense present)
                             (aspect (perfect -)
                                     (progressive -))))
               (lex-id dance)
               --
               (HASH form ((string ?dances-unit "dances")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn dance->dancing-morph
             ((?dancing-unit
               (footprints (number morph)))
              <-
              (?dancing-unit
               (footprints (not number morph))
               (syn-cat (lex-class verb)
                        (verb-form gerund)
                        (finite -)
                        (agreement ?agr)
                        (tam (tense ?tense)
                             (aspect (perfect ?p)
                                     (progressive +))
                             ))
               (lex-id dance)
               --
               (HASH form ((string ?dancing-unit "dancing")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn dance->dance-morph
             ((?dance-unit
               (footprints (number morph)))
              <-
              (?dance-unit
               (footprints (not number morph))
               (syn-cat (lex-class verb)
                        (verb-form base-form)
                        (tam (tense ?tense)
                             (aspect (perfect -)
                                     (progressive -)))
                        (agreement (not (person 3))))
               (lex-id dance)
               --
               (HASH form ((string ?dance-unit "dance")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn dance->danced-participle-morph
             ((?danced-unit
               (footprints (number morph)))
              <-
              (?aux-unit
               (syn-cat (lex-class aux))
               --
               (syn-cat (lex-class aux)))
              (?danced-unit
               (footprints (not number morph))
               (syn-cat (lex-class verb)
                        (verb-form participle)
                        (tam (tense ?tense)
                             (aspect (perfect +)
                                     (progressive -))))
               (lex-id dance)
               --
               (HASH form ((string ?danced-unit "danced")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn dance->danced-preterite-morph
             ((?danced-unit
               (footprints (number morph)))
              <-
              (?danced-unit
               (footprints (not number morph))
               (syn-cat (lex-class verb)
                        (verb-form base-form)
                        (tam (tense past)
                             (aspect ?aspect)
                             ))
               (lex-id dance)
               --
               (HASH form ((string ?danced-unit "danced")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn hour-noun-lex
             ((?hour-unit
               (footprints (lex))
               (referent ?ref)
               (sem-cat (sem-class temporal-unit)))
              <-
              (?hour-unit
               (HASH meaning ((temporal-unit hour ?ref)))
               --
               (lex-id hour)
               (footprints (not lex))
               (syn-cat (lex-class noun)
                        (agreement ?agr))))
             :disable-automatic-footprints t
             :cxn-set lex)

(def-fcg-cxn hours-noun-morph
             ((?hours-unit
               (footprints (morph)))
               <-
              (?hours-unit
               (lex-id hour)
               (footprints (not morph))
               (syn-cat (lex-class noun)
                        (agreement (person 3)
                                   (number pl)))
               --
               (HASH form ((string ?hours-unit "hours")))))
             :disable-automatic-footprints t
             :cxn-set morph)

(def-fcg-cxn day-noun-lex
             ((?day-unit
               (footprints (lex))
               (referent ?ref)
               (sem-cat (sem-class temporal-unit)))
              <-
              (?day-unit
               (HASH meaning ((temporal-unit day ?ref)))
               --
               (lex-id day)
               (footprints (not lex))
               (syn-cat (lex-class noun)
                        (agreement ?agr))))
             :disable-automatic-footprints t
             :cxn-set lex)

(def-fcg-cxn day-noun-morph
             ((?day-unit
               (footprints (morph)))
               <-
              (?day-unit
               (lex-id day)
               (footprints (not morph))
               (syn-cat (lex-class noun)
                        (agreement (person 3)
                                   (number sg)))
               --
               (HASH form ((string ?day-unit "day")))))
             :disable-automatic-footprints t
             :cxn-set morph)

(def-fcg-cxn the-lex
             ((?the-unit
               (referent ?ref)
               (sem-cat (sem-class selector))
               (syn-cat (lex-class article)
                        (is-definite +)
                        (agreement (person 3)
                                   (number ?nb))))
              <-
              (?the-unit
               (HASH meaning ((referent-status identifiable ?ref)))
               --
               (HASH form ((string ?the-unit "the")))))
             :cxn-set lex)

(def-fcg-cxn a-lex
             ((?a-unit
               (referent ?ref)
               (sem-cat (sem-class selector))
               (syn-cat (lex-class article)
                        (is-definite -)
                        (agreement (person 3)
                                   (number sg))))
              <-
              (?a-unit
               (HASH meaning ((referent-status introducing ?ref)))
               --
               (HASH form ((string ?a-unit "a")))))
             :cxn-set lex)

(def-fcg-cxn every-lex
             ((?every-unit
               (referent ?ref)
               (sem-cat (sem-class quantify-referent)
                        (quantifier-type every)) ;;????
               (syn-cat (lex-class quantifier)
                        ;(is-definite +)
                        (agreement (person 3)
                                   (number sg))))
              <-
              (?every-unit
               (HASH meaning ((quantify-referent every ?ref)))
               --
               (HASH form ((string ?every-unit "every")))))
             :cxn-set lex)

(def-fcg-cxn three-lex
             ((?three-unit
               (referent ?ref)
               (sem-cat (sem-class selector))
               (syn-cat (lex-class numeral)
                        (is-definite +)
                        (agreement (person 3)
                                   (number ?nb))))
              <-
              (?three-unit
               (HASH meaning ((referent-status three ?ref)))
               --
               (HASH form ((string ?three-unit "three")))))
             :cxn-set lex)
  
(def-fcg-cxn article-noun-cxn 
         ((?np-unit
           (referent ?ref)
           (subunits (?article-unit ?noun-unit))
           (leftmost-unit ?article-unit)
           (rightmost-unit ?noun-unit)
           (sem-cat (sem-function referring-expression)
                    (is-determined +) ;;contains determiner
                    (sem-role ?sem-role))
           (syn-cat (phrase-type np)
                    (syn-role ?syn-role)
                    (agreement ?agreement)))
          <-
          (?article-unit
           (referent ?ref)
           (sem-cat (sem-class selector))
           (syn-cat (lex-class article))
           --
           (syn-cat (lex-class article)
                    (agreement ?agreement)
                    (is-definite ?def-or-indef)))

          (?noun-unit
           (referent ?ref) 
           (syn-cat (lex-class noun))
           --
           (syn-cat (lex-class noun)
                    (agreement ?agreement)))
          (?np-unit
           --
           (HASH form ((meets ?article-unit ?noun-unit))))))

(def-fcg-cxn quantifier-every-noun-cxn 
         ((?np-unit
           (referent ?ref)
           (subunits (?quantifier-unit ?noun-unit))
           (leftmost-unit ?quantifier-unit)
           (rightmost-unit ?noun-unit)
           (sem-cat (sem-function adverbial)
                    (is-quantified +) ;;contains quantifier
                    (sem-role ?sem-role)
                    (adverbial-type frequency))
           (syn-cat (phrase-type np)
                    (syn-role ?syn-role)
                    (agreement ?agreement)))
          <-
          (?quantifier-unit
           (referent ?ref)
           (sem-cat (sem-class quantify-referent)
                    (quantifier-type every))
           --
           (syn-cat (lex-class quantifier)
                    (agreement ?agreement) ))
          (?noun-unit
           (referent ?ref) 
           (syn-cat (lex-class noun))
           --
           (syn-cat (lex-class noun)
                    (agreement ?agreement)))
          (?np-unit
           --
           (HASH form ((meets ?quantifier-unit ?noun-unit))))))

(def-fcg-cxn numeral-noun-cxn 
         ((?np-unit
           (referent ?ref)
           (subunits (?numeral-unit ?noun-unit))
           (leftmost-unit ?numeral-unit)
           (rightmost-unit ?noun-unit)
           (sem-cat (sem-function referring-expression)
                    (sem-class ?class)
                    (is-determined +) ;;contains determiner
                    (sem-role ?sem-role))
           (syn-cat (phrase-type np)
                    (syn-role ?syn-role)
                    (agreement ?agreement)))
          <-
          (?numeral-unit
           (referent ?ref)
           (sem-cat (sem-class selector))
           (syn-cat (lex-class numeral))
           --
           (syn-cat (lex-class numeral)
                    (agreement ?agreement)
                    (is-definite +)))

          (?noun-unit
           (referent ?ref)
           (sem-cat (sem-class ?class))
           (syn-cat (lex-class noun))
           --
           (syn-cat (lex-class noun)
                    (agreement ?agreement)))
          (?np-unit
           --
           (HASH form ((meets ?numeral-unit ?noun-unit))))))

(def-fcg-cxn durative-for-prep-phrase-cxn
             ((?prep-phrase-unit
               (referent ?ref)
               (subunits (?np-unit))
               (syn-cat (phrase-type pp)))
              <-
              (?frame-unit
               (referent ?frame)
               --
               (sem-cat (frame ?some-frame)))
              (?prep-phrase-unit
               (HASH meaning ((slot duration ?frame ?ref)))
               --
               (HASH form ((string ?prep-phrase-unit "for")
                           (meets ?prep-phrase-unit ?leftmost-np-unit))))
              (?np-unit
               (referent ?ref)
               (sem-cat (sem-class temporal-unit)
                        (sem-function referring-expression))
               --
               (sem-cat (sem-class temporal-unit))
               (leftmost-unit ?leftmost-np-unit))))
               

(def-fcg-cxn verb-phrase-cxn 
             ((?vp-unit
               (referent ?ref)
               (subunits (?main-verb-unit))
               (sem-valence ?sem-valence)
               (sem-cat (sem-function predicating-expression)
                        (aspectual-contour ?asp))
               (syn-cat (syn-function verbal)
                        (phrase-type vp)
                        (tam ?tam)
                        (agreement ?agreement))
               (leftmost-unit ?main-verb-unit)
               (rightmost-unit ?main-verb-unit))
              (?main-verb-unit
               (footprints (vp-cxn)))
              <-
              (?main-verb-unit
               (referent ?ref)
               (sem-cat (sem-class event)
                        (aspectual-contour ?asp))
               (sem-valence ?sem-valence)
               (footprints (not vp-cxn))
               --
               (footprints (not vp-cxn))
               (syn-cat (lex-class verb)
                        (tam ?tam)
                        (agreement ?agreement))))
             :disable-automatic-footprints t)
         

(def-fcg-cxn active-intransitive-cxn
             ((?intransitive-clause
               (subunits (?subject ?vp-phrase))
               (referent ?event)
               (sem-cat (sem-function proposition)
                        (aspectual-contour ?asp))
               (syn-cat (clause-type intransitive)
                        (voice active))
               (leftmost-unit ?subj-left)
               (rightmost-unit ?vp-right))
              (?vp-phrase
               (footprints (argument-structure))
               (syn-valence (subject ?subject)))
              <-
              (?subject
               (referent ?actor)
               (sem-cat (sem-role agent))
               --
               (syn-cat (syn-role subject)
                        (agreement ?agreement))
               (leftmost-unit ?subj-left)
               (rightmost-unit ?subj-right))
              (?vp-phrase
               (referent ?event)
               (sem-valence (actor ?actor))
               (sem-cat (sem-function predicating-expression)
                        (aspectual-contour ?asp))
               (footprints (not argument-structure))
               --
               (footprints (not argument-structure))
               (leftmost-unit ?vp-left)
               (rightmost-unit ?vp-right)
               (syn-cat (agreement ?agreement))
               (HASH form ((meets ?subj-right ?vp-left)))))
             :disable-automatic-footprints t)

(def-fcg-cxn active-transitive-cxn
             ((?transitive-clause
               (subunits (?subject ?vp-phrase ?direct-object))
               (referent ?event)
               (sem-cat (sem-function proposition)
                        (aspectual-contour ?asp))
               (syn-cat (clause-type transitive)
                        (voice active))
               (leftmost-unit ?subj-left)
               (rightmost-unit ?obj-right))
              (?vp-phrase
               (footprints (argument-structure))
               (syn-valence (subject ?subject)
                            (object ?direct-object))
               (sem-valence (actor ?actor)
                            (theme ?theme)))
              <-
              (?subject
               (referent ?actor)
               (sem-cat (sem-role agent))
               --
               (syn-cat (syn-role subject)
                        (agreement ?agreement))
               (leftmost-unit ?subj-left)
               (rightmost-unit ?subj-right))
              (?vp-phrase
               (referent ?event)
               (HASH meaning ((theme ?event ?theme)))
               (sem-cat (sem-function predicating-expression)
                        (aspectual-contour ?asp))
               (footprints (not argument-structure))
               --
               (footprints (not argument-structure))
               (leftmost-unit ?vp-left)
               (rightmost-unit ?vp-right)
               (syn-cat (agreement ?agreement))
               (HASH form ((meets ?subj-right ?vp-left)
                           (meets ?vp-right ?obj-left))))
              (?direct-object
               (referent ?theme)
               (sem-cat (sem-role theme))
               --
               (syn-cat (syn-role object))
               (leftmost-unit ?obj-left)
               (rightmost-unit ?obj-right)))
             :disable-automatic-footprints t)

(def-fcg-cxn have->has-morph
             ((?has-unit
               (footprints (number morph)))
              <-
              (?has-unit
               (footprints (not number morph))
               (syn-cat (lex-class aux)
                        (finite +)
                        (agreement (person 3)
                                   (number sg))
                        (tam (tense present)
                             (aspect (perfect +)
                                     (progressive -))))
               (lex-id have)
               --
               (HASH form ((string ?has-unit "has")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn be->is-morph
             ((?is-unit
               (footprints (number morph)))
              <-
              (?is-unit
               (footprints (not number morph))
               (syn-cat (lex-class aux)
                        (finite +)
                        (agreement (person 3)
                                   (number sg))
                        (tam (tense present)
                             (aspect (perfect -)
                                     (progressive -))))
               (lex-id be)
               --
               (HASH form ((string ?is-unit "is")))))
            :disable-automatic-footprints t
            :cxn-set morph)

(def-fcg-cxn perfect-cxn
             ((?vp-unit
               (referent ?ev)
               (subunits (?aux-have-unit ?participle-unit))
               (sem-valence ?sem-valence)
               (sem-cat (sem-function predicating-expression)
                        (aspectual-contour ?asp))
               (syn-cat (syn-function verbal)
                        (phrase-type vp)
                        (tam (tense ?tense)
                             (aspect (perfect +)
                                     (progressive -)))
                        (agreement ?agreement))
               (leftmost-unit ?aux-have-unit)
               (rightmost-unit ?participle-unit)
               (footprints (aspectual-contour)))
              (?participle-unit
               (footprints (vp-cxn)))
              
              <-
              (?vp-unit
               --
               (HASH form ((meets ?aux-have-unit ?participle-unit))))
              (?aux-have-unit
               (HASH meaning ((aspectual-contour transitory-state occured not-occured ?ev)))
               --
               (lex-id have)
               (syn-cat (lex-class aux)
                        (finite +)
                        (agreement ?agreement)
                        (tam (tense ?tense)
                             (aspect (perfect +)
                                     (progressive -)))))
               
              (?participle-unit
               (referent ?ev)
               (sem-cat (sem-class event)
                        (aspectual-contour ?asp))
               (sem-valence ?sem-valence)
               (footprints (not vp-cxn))
               --
               (footprints (not vp-cxn))
               (syn-cat (lex-class verb)
                        (finite -)
                        (verb-form participle)
                        (tam (tense ?tense)
                             (aspect (perfect +)
                                     (progressive -))))))
             :disable-automatic-footprints t)


(def-fcg-cxn progressive-cxn
             ((?vp-unit
               (referent ?ev)
               (subunits (?aux-unit ?gerund-unit))
               (sem-valence ?sem-valence)
               (sem-cat (sem-function predicating-expression)
                        (aspectual-contour ?asp))
               (syn-cat (syn-function verbal)
                        (phrase-type vp)
                        (tam (tense ?tense)
                             (aspect (perfect -)
                                     (progressive +)))
                        (agreement ?agreement))
               (leftmost-unit ?aux-unit)
               (rightmost-unit ?gerund-unit)
               (footprints (aspectual-contour)))
              (?gerund-unit
               (footprints (vp-cxn)))
              
              <-
              (?vp-unit
               --
               (HASH form ((meets ?aux-unit ?gerund-unit))))
              (?aux-unit
               (HASH meaning ((aspectual-contour transitory-state low-q high-q ?ev)))
               --
               (lex-id be)
               (syn-cat (lex-class aux)
                        (finite +)
                        (tam (tense ?tense)
                             (aspect (perfect -)
                                     (progressive -)))
                        (agreement ?agreement)))
              (?gerund-unit
               (referent ?ev)
               (sem-cat (sem-class event)
                        (aspectual-contour ?asp))
               (sem-valence ?sem-valence)
               (footprints (not vp-cxn))
               --
               (footprints (not vp-cxn))
               (syn-cat (lex-class verb)
                        (finite -)
                        (verb-form gerund)
                        (tam (tense ?tense)
                             (aspect (perfect -)
                                     (progressive +))))))
             :disable-automatic-footprints t)


(def-fcg-cxn present-tense-undirected-activity-to-generic-property-cxn
             ((?vp-unit
               (footprints (aspectual-contour)))
              (?finite-unit
               (syn-cat (verb-form base-form)))
              <-
              (?vp-unit
               (referent ?frame)
               (sem-cat (sem-function predicating-expression))
               (subunits (?finite-unit))
               (footprints (not aspectual-contour))
               --
               (footprints (not aspectual-contour))
               (subunits (?finite-unit))
               (syn-cat (phrase-type vp)))
              (?finite-unit
               (referent ?frame)
               --
               (syn-cat (finite +)
                        (tam (tense present)
                             (aspect (perfect ?pf)
                                     (progressive ?prog)))))
              (?clause-unit
               (HASH meaning ((aspectual-contour generic-property ?frame)))
               (sem-cat (sem-function proposition)
                        (aspectual-contour undirected-activity))
               --
               (syn-cat (voice active))))
             :disable-automatic-footprints t
             :description "The man smokes")

(def-fcg-cxn past-tense-undirected-activity-to-accomplishment-cxn
             ((?vp-unit
               (footprints (aspectual-contour)))
              (?finite-unit
               (syn-cat (verb-form base-form)))
               
              <-
              (?transitive-clause-unit
               (referent ?event)
               (sem-cat (sem-function proposition)
                        (aspectual-contour undirected-activity))
               (HASH meaning ((aspectual-contour incremental-accomplishment ?event)))
               --
               (syn-cat (voice active)
                        (clause-type transitive)))
              (?vp-unit
               (sem-cat (sem-function predicating-expression))
               (subunits (?finite-unit))
               (syn-valence (object ?np-unit))
               --
               (subunits (?finite-unit))
               (syn-cat (phrase-type vp))
               (syn-valence (object ?np-unit))
               (footprints (not aspectual-contour)))
              (?finite-unit
               (referent ?event)
               (syn-cat (finite +))
               --
               (syn-cat (finite +)
                        (tam (tense past)
                             (aspect (perfect ?pf)
                                     (progressive ?prog)))))
              (?np-unit
               (sem-cat (sem-function referring-expression)
                        (is-determined +))
               --
               (syn-cat (phrase-type np)
                        (syn-role object))))
             :disable-automatic-footprints t
             :description "The man smoked the cigarette")


(def-fcg-cxn past-tense-undirected-activity-because-of-durative-prep-phrase-cxn
             ((?transitive-clause
               (subunits (?durative-prep-phrase)))
              (?vp-unit
               (footprints (aspectual-contour)))
              (?finite-unit
               (syn-cat (verb-form base-form)))
              <-
              (?vp-unit
               (referent ?ev)
               (sem-cat (sem-function predicating-expression))
               (footprints (not aspectual-contour))
               --
               (footprints (not aspectual-contour))
               (subunits (?finite-unit))
               (syn-valence (object ?np-unit))
               (syn-cat (phrase-type vp)))
              (?finite-unit
               (referent ?ev)
               (syn-cat (finite +))
               --
               (syn-cat (finite +)
                        (tam (tense past)
                             (aspect (perfect ?pf)
                                     (progressive ?prog)))))
              (?transitive-clause
               (referent ?ev)
               (sem-cat (sem-function proposition)
                        (aspectual-contour undirected-activity))
               (HASH meaning ((aspectual-contour undirected-activity ?ev)))
               --
               (syn-cat (voice active)))
              (?durative-prep-phrase
               (referent ?duration)
               (meaning ((slot duration ?ev ?duration)))
               --
               (syn-cat (phrase-type pp)))
              (?np-unit
               (sem-cat (is-determined +))
               --
               (syn-cat (syn-role object))))
             :disable-automatic-footprints t
             :description "The man smoked the cigarette for three hours")


(def-fcg-cxn past-tense-undirected-activity-to-generic-property-because-of-frequency-adverbial-cxn
             ((?transitive-clause
               (subunits (?adverbial-phrase)))
              (?vp-unit
               (footprints (aspectual-contour)))
              (?finite-unit
               (syn-cat (verb-form base-form)))
              <-
              (?vp-unit
               (referent ?ev)
               (sem-cat (sem-function predicating-expression))
               (footprints (not aspectual-contour))
               --
               (footprints (not aspectual-contour))
               (subunits (?finite-unit))
               (syn-valence (object ?np-unit))
               (syn-cat (phrase-type vp)))
              (?finite-unit
               (referent ?ev)
               (syn-cat (finite +))
               --
               (syn-cat (finite +)
                        (tam (tense past)
                             (aspect (perfect ?pf)
                                     (progressive ?prog)))))
              (?transitive-clause
               (referent ?ev)
               (sem-cat (sem-function proposition)
                        (aspectual-contour undirected-activity))
               (HASH meaning ((aspectual-contour generic-property ?ev)))
               --
               (syn-cat (voice active)))
              (?adverbial-phrase
               (referent ?frequency)
               (HASH meaning ((slot frequency ?ev ?frequency)))
               (sem-cat (sem-function adverbial)
                        (adverbial-type frequency))
               --
               (sem-cat (sem-function adverbial)
                        (adverbial-type frequency))
               (syn-cat (phrase-type np)))
              (?np-unit
               (sem-cat (is-determined +))
               --
               (syn-cat (syn-role object)))))


(def-fcg-cxn past-tense-undirected-activity-cxn
             ((?vp-unit
               (footprints (aspectual-contour)))
              (?finite-unit
               (syn-cat (verb-form base-form)))
              <-
              (?transitive-clause-unit
               (referent ?event)
               (sem-cat (sem-function proposition)
                        (aspectual-contour undirected-activity))
               (HASH meaning ((aspectual-contour undirected-activity ?event)))
               --
               (syn-cat (voice active)
                        (clause-type intransitive)))
              (?vp-unit
               (sem-cat (sem-function predicating-expression))
               (subunits (?finite-unit))
               (footprints (not aspectual-contour))
               --
               (footprints (not aspectual-contour))
               (subunits (?finite-unit))
               (syn-cat (phrase-type vp))
               (footprints (not aspectual-contour)))
              (?finite-unit
               (referent ?event)
               (syn-cat (finite +))
               --
               (syn-cat (finite +)
                        (tam (tense past)
                             (aspect (perfect ?pf)
                                     (progressive ?prog)))))
              )
             :disable-automatic-footprints t
             :description "The man danced")


)




