;; This file contains instructions to load the grammar fragment that
;; was defined in construction.lisp as well as example sentences that
;; can be tested in comprehension and formulation.

;; To evaluate a certain line, please put your cursor behind the final
;; bracket and press Ctrl-X Ctrl-E. You will see the result in the bar
;; a the bottom of your screen. Wait to evaluate the next expression
;; until you received feedback in that bar.

;; First load FCG (not needed if you are using the FCG editor)
(ql:quickload :fcg)
(in-package :fcg)

;; Then load the Croft grammar fragment (it assumes you have a
;; subfolder course-materials in the Babel2 folder in which you put
;; the folder iccg-10 that contains this file and constructions.lisp)
(load (babel-pathname :directory '("course-materials" "iccg-10") :name "constructions" :type "lisp"))

;; Now activate the FCG monitor so you can use the web interface at http://localhost:8000
(activate-monitor trace-fcg)

;;---------------------------------------------------------------------------------------
;; The constructions we implemented can handle sentences with the verb
;; 'to dance', which is analysed as an undirected activity. The
;; grammar fragment currently covers eight different types of
;; sentences with 'dance', resulting in five different aspectual
;; contours:

;; 1) present: generic-property
;;--------------------------------------------------------------
(comprehend "the man dances")

(formulate '((referent-status identifiable bill)
             (person man bill)
             (frame self-motion dance dancing-frame)
             (slot self-mover dancing-frame bill)
             (aspectual-contour generic-property dancing-frame)))
             

;; 2) present: generic-property
;;--------------------------------------------------------------
(comprehend "the man dances the sirtaki")
(comprehend-and-formulate "the man dances the sirtaki")


;; 3) past tense: undirected activity
;;--------------------------------------------------------------
(comprehend "the man danced")
(comprehend-and-formulate "the man danced")


;; 4) past tense + count noun object: incremental-accomplishment
;;--------------------------------------------------------------
(comprehend "the man danced the sirtaki")
(comprehend-and-formulate "the man danced the sirtaki")


;; 5) past tense + count noun object + durative adverb: undirected activity
;;--------------------------------------------------------------
(comprehend "the man danced the sirtaki for three hours")
(comprehend-and-formulate "the man danced the sirtaki for three hours")


;; 6) past tense + count noun object + frequency adverb: generic property
;;--------------------------------------------------------------
(comprehend "the man danced the sirtaki every day")
(comprehend-and-formulate "the man danced the sirtaki every day")


;; 7) progressive: transitory-state low-q high-q
;;--------------------------------------------------------------
(comprehend "the man is dancing the sirtaki")
(comprehend-and-formulate "the man is dancing the sirtaki")


;; 8) perfect: transitory state occured - not occured
;;--------------------------------------------------------------
(comprehend "the man has danced the sirtaki")
(comprehend-and-formulate "the man has danced the sirtaki")


